@@ -66,7 +66,6 @@ from docopt import docopt
 from openaccess_epub._version import __version__
 from openaccess_epub.navigation import Navigation
 from openaccess_epub.package import Package
-import openaccess_epub.ops as ops
 import openaccess_epub.utils as utils
 from openaccess_epub.utils.epub import epub_zip, make_epub_base
 import openaccess_epub.utils.images
@@ -153,6 +152,7 @@ def main(argv=None):
                 epub_version = 3
             else:
                 epub_version = parsed_article.publisher.epub_default
+
         navigation.process(parsed_article)
         package.process(parsed_article)
 
@@ -167,14 +167,13 @@ def main(argv=None):
                                                 config,
                                                 parsed_article)
 
-        if journal_doi == '10.1371':  # PLoS's publisher DOI
-            ops_doc = ops.OPSPLoS(parsed_article, output_directory)
+        parsed_article.publisher.render_content(output_directory, epub_version)
 
     if epub_version == 2:
         navigation.render_EPUB2(output_directory)
         package.render_EPUB2(output_directory)
     elif epub_version == 3:
-        navigation.render_EPUB3(output_directory, back_compat=True)
+        navigation.render_EPUB3(output_directory)
         package.render_EPUB3(output_directory)
     epub_zip(output_directory)
 
