@@ -1,10 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-This module defines a set of methods for XML document parsing and manipulation
-patterns beyond those which are provided by xml.dom.minidom.
-
-Incorporating these methods into the module provides a single definition point
-for the method that may be utilized in different sections.
+Advanced XML manipulation methods built on core lxml functionality.
 """
 
 from lxml import etree
@@ -14,8 +10,17 @@ import xml.parsers.expat
 import html.parser
 import logging
 
+#TODO: Remove get_attribute method, remove it's mention in __all__
+__all__ = ['append_new_text', 'append_all_below', 'all_text', 'comment',
+           'elevate_element', 'get_attribute', 'insert_before', 'ns_format',
+           'remove', 'remove_all_attributes', 'rename_attributes', 'replace',
+           'serialize', 'uncomment']
+
 log = logging.getLogger('openaccess_epub.utils.element_methods')
 
+#TODO: I should add some handy recursive iteration extension methods
+
+
 def append_new_text(destination, text, join_str=None):
     """
     This method provides the functionality of adding text appropriately
@@ -36,6 +41,7 @@ def append_new_text(destination, text, join_str=None):
         else:  # Destination has a text
             destination.text = join_str.join([destination.text, text])
 
+
 def append_all_below(destination, source, join_str=None):
     """
     Compared to xml.dom.minidom, lxml's treatment of text as .text and .tail
@@ -63,11 +69,12 @@ def append_all_below(destination, source, join_str=None):
     for each_child in source:
         destination.append(deepcopy(each_child))
 
+
 def all_text(element):
     """
     A method for extending lxml's functionality, this will find and concatenate
     all text data that exists one level immediately underneath the given
-    element. Unlike etree.tostring(element, method='text'), this will not 
+    element. Unlike etree.tostring(element, method='text'), this will not
     recursively walk the entire underlying tree. It merely combines the element
     text attribute with the tail attribute of each child.
     """
@@ -79,6 +86,7 @@ def all_text(element):
     tails = [tail.strip() for tail in tails if tail.strip()]
     return ' '.join(text + tails)
 
+
 def remove_all_attributes(element, exclude=None):
     """
     This method will remove all attributes of any provided element.
@@ -92,40 +100,38 @@ def remove_all_attributes(element, exclude=None):
         if k not in exclude:
             element.attrib.pop(k)
 
+
 def get_attribute(element, attribute):
     """
-    With lxml's built in methods, if you attempt to access an attribute
-    that does not exist, you will get a KeyError. To deal with attributes
-    that are optional, you would have to follow one of these patterns:
+    Gets the attribute value in a safe way, useful for optional attributes.
 
-      try:
-        optional_attr = some_element.attrib['optional']
-      except KeyError:
-        optional_attr = None
-      if optional_attr:  # Or this could be an else clause
-        do_stuff
+    .. note:: deprecated in OpenAccess_EPUB 0.5.5
+        get_attribute achieves the same functionality as dict.get on the attrib
+        dictionary of an Element. In the future, Element.attrib.get['foo']
+        should be used.
 
-      if 'optional' in some_element.attrib:
-        optional_attr = some_element.attrib['optional']
-      else:
-        optional_attr = None
-      if optional_attr:
-        do_stuff
+    .. note:: OpenAccess_EPUB 0.6.0 replaces this precisely with
+        Element.attrib.get['foo'], further updates will remove this method
+        completely
 
-    Doing this for such a common job may be an annoyance, so this method
-    encapsulates the first pattern above to make things cleaner. The new
-    pattern, using this method, is:
+    lxml Elements possess a dictionary called 'attrib', but as many attributes
+    are optional, use of optional-safe attribute accession is needed as the key
+    may not always be present.
 
-      optional_attr = get_attribute(some_element, 'optional')
-      if optional_attr:
-        do_stuff
+    Parameters
+    ----------
+    element : lxml.etree.Element object
+        The `element` whose attribute value is being sought
+    attribute : str
+        The name of the attribute whose value is being sought
+
+    Returns
+    -------
+    attr_value : str or None
+        The string value of the attribute, None if it does not exist.
     """
-    try:
-        optional_attribute = element.attrib[attribute]
-    except KeyError:
-        return None
-    else:
-        return optional_attribute
+    return element.attrib.get(attribute)
+
 
 def ns_format(element, namespaced_string):
     """
@@ -139,6 +145,7 @@ def ns_format(element, namespaced_string):
     namespace, name = namespaced_string.split(':')
     return '{' + element.nsmap[namespace] + '}' + name
 
+
 def rename_attributes(element, attrs):
     """
     Renames the attributes of the element. Accepts the element and a dictionary
@@ -217,7 +224,7 @@ def replace(old, new):
     """
     A simple way to replace one element node with another.
     """
-    parent  = old.getparent()
+    parent = old.getparent()
     parent.replace(old, new)
 
 
@@ -262,3 +269,12 @@ def uncomment(comment):
         parent.replaceChild(node, comment)
         return node
 
+
+def serialize(element, strip=False):
+    """
+    A handy way to serialize an element to text.
+    """
+    text = etree.tostring(element, method='text', encoding='utf-8')
+    if strip:
+        text = text.strip()
+    return str(text, encoding='utf-8')
